#include "testlib.h"
#include <string>
#include <algorithm>
#include <vector>

const int MAXX = 8;
const int MAXN = 100000;
const int MAXC = 255;

int n, x;

std::vector<std::string> split(std::string &s) {
  std::vector<std::string> answer;
  std::string current;
  s += '.';
  for (int i = 0; i < (int)s.size(); i++) {
    if (s[i] == '.')
      answer.push_back(current), current = "";
    else
      current += s[i];
  }
  return answer;
}

bool is_number(const std::string &s) {
  if (s == "0") return true;
  if (s[0] < '1' || s[0] > '9') return false;
  for (int i = 1; i < (int)s.size(); i++) {
    if (s[i] < '0' || s[i] > '9') return false;
  }
  return true;
}

void check(const std::vector<std::string> &parts, const std::string &name) {
  if (parts.size() != x) quitf(_fail, ("address " + name + " should have " + std::to_string(x) + " parts").c_str());
  for (int i = 0; i < x; i++) {
    if (parts[i] == "" || !is_number(parts[i])) quitf(_fail, ("address " + name + " should have numbers in its parts").c_str());
    int number = std::stoi(parts[i]);
    if (number < 0 || number > MAXC) quitf(_fail, ("address " + name + " should contain numbers in parts in range [0, 255]").c_str());
  }
}

int main(int argc, char* argv[])
{
  registerValidation(argc, argv);
  n = inf.readInt(0, MAXN, "n");
  inf.readSpace();
  x = inf.readInt(1, MAXX, "x");
  inf.readEoln();
  std::string tmp;
  std::set<std::string> addresses;
  for (int i = 0; i < n; i++) {
    tmp = inf.readString();
    std::vector<std::string> parts = split(tmp);
    addresses.insert(tmp);
    check(parts, "addresses[" + std::to_string(i + 1) + "]");  
  }
  if ((int)addresses.size() != n) {
    quitf(_fail, "all n addreses should be pairwise distinct");
  }
  tmp = inf.readString();
  std::vector<std::string> a = split(tmp);
  tmp = inf.readString();
  std::vector<std::string> b = split(tmp);
  check(a, std::string("a"));
  check(b, std::string("b"));
  std::vector<int> aa(a.size());
  std::vector<int> bb(b.size());
  for (int i = 0; i < (int)a.size(); i++) {
    aa[i] = std::stoi(a[i]);
    bb[i] = std::stoi(b[i]);
  }
  if (aa >= bb) quitf(_fail, "First address is not less than the second one");
  inf.readEof();
  return 0;
}
